<template>
  <div class="container">
    <div class="main-content">
      <div class="list">
        <div v-for="item in state.dataList" @click="openDetails('通知公告',item.id)">
          <div>
            <div><img :src="articlePng"></div>
            <div>{{item.title}}</div>
          </div>
          <span>
            {{(item.updateTime?item.updateTime:item.createTime).substring(0,16)}}
          </span>
        </div>
      </div>
      <div class="pag-container" v-if="state.total&&state.total>0">
        <el-pagination
            :page-sizes="[10,15,20]"
            layout="total, sizes, prev, pager, next, jumper"
            :total="state.total"
            :current-page="state.querys.pageNum"
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
        />
      </div>
    </div>
  </div>
</template>

<script setup>
import {onMounted, ref, reactive, watch, onUnmounted, defineExpose, defineEmits} from "vue"
import { getNotice } from '@/api/home/homePage'
import useUserStore from '@/store/modules/user'
import {ElMessage} from "element-plus";
import articlePng from "@/assets/images/article.png";
const emit = defineEmits(['openDetails'])
const route = useRoute()
const router = useRouter()

const state = reactive({
  dataList: [],
  querys:{
    title: '',
    content: '',
    pageNum: 1,
    pageSize: 10
  },
  total: null
})

const redirect = ref(undefined);

onMounted(()=>{
  getData()
})

onUnmounted(()=>{

})

watch(route, (newRoute) => {
    redirect.value = newRoute.query && newRoute.query.redirect;
}, { immediate: true });

const handleSizeChange = (val) => {
    state.querys.pageNum = 1
  state.querys.pageSize = val
  getData()
}
const handleCurrentChange = (val) => {
  state.querys.pageNum = val
  getData()
}

const getData = async ()=>{
  const res = await getNotice(state.querys)
  if(res.code == 200){
    state.dataList = res.data.list
    state.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
}

const openDetails = (type,id)=>{
  emit('openDetails',type,id)
}

defineExpose({
  getData
})

</script>

<style lang='scss' scoped>
.container {
  width: 100%;
  display: flex;
  justify-content: center;
  margin-top: 160px;

  .main-content{
    width: 1200px;
    margin: 15px 0;
    background: #fff;
    border-radius: 4px;
    box-shadow: 1px 1px 3px rgba(0,0,0,.04);
    padding: 0 10px;
    color: #333;

    .list{
      padding: 15px 0;
      height: calc(100vh - 330px);
      overflow-y: auto;

      &>div{
        display: flex;
        padding: 10px;
        align-items: center;
        justify-content: space-between;
        border-bottom: 1px dashed #ebeef5;
        cursor: pointer;
        border-radius: 4px;
        font-size: 16px;

        &>div{
          display: flex;
          align-items: center;

          div:first-of-type{
            width: 40px;
            height: 40px;
            margin-right: 10px;
            display: flex;
            justify-content: center;
            align-items: center;

            img{
              width: 28px;
              height: 28px;
            }
          }
          div:last-of-type{
            width: 900px;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
            font-family: "PingFang SC";
          }
        }
        span{
          color: #999;
        }
        &:hover{
          background: #f5f5f5;
        }
        &:active{
          background: #425f9f;
          color: #fff;
        }
      }
    }

    .pag-container{
      width: 100%;
      height: 80px;
      display: flex;
      align-items: center;
      justify-content: right;
    }
  }
}
</style>
